from distutils.core import setup
setup(
    name = 'nestersows',
    version = '1.2.0',
    py_modules = ['nestersows'],
    author = 'jaytj005',
    author_email = 'jaytj005@yahoo.com',
    url = 'https://www.w3schools.com',
    description = 'A simple printer of nested lists'

    )
